"""
    Core files for the Flask Monitoring Dashboard
    - auth.py handles authentication
    - forms.py are used for generating WTF_Forms
    - measurements.py contains a number of wrappers
    - outlier.py contains outlier information
"""